==> open-cluster-management-apps-model-6.2.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ObjectStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObjectStatusFluentImpl<A extends ObjectStatusFluent<A>> extends BaseFluent<A> implements ObjectStatusFluent<A>{
  public ObjectStatusFluentImpl() {
  }
  public ObjectStatusFluentImpl(ObjectStatus instance) {
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withLink(instance.getLink()); 
    this.withName(instance.getName()); 
    this.withStatus(instance.getStatus()); 
  }
  private String group;
  private String kind;
  private String link;
  private String name;
  private String status;
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public String getLink() {
    return this.link;
  }
  public A withLink(String link) {
    this.link=link; return (A) this;
  }
  public Boolean hasLink() {
    return this.link != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getStatus() {
    return this.status;
  }
  public A withStatus(String status) {
    this.status=status; return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObjectStatusFluentImpl that = (ObjectStatusFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (link != null ? !link.equals(that.link) :that.link != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  link,  name,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (link != null) { sb.append("link:"); sb.append(link + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ObjectStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObjectStatusFluentImpl<A extends ObjectStatusFluent<A>> extends BaseFluent<A> implements ObjectStatusFluent<A>{
  public ObjectStatusFluentImpl() {
  }
  public ObjectStatusFluentImpl(ObjectStatus instance) {
    if (instance != null) {
      this.withGroup(instance.getGroup());
      this.withKind(instance.getKind());
      this.withLink(instance.getLink());
      this.withName(instance.getName());
      this.withStatus(instance.getStatus());
    }
  }
  private String group;
  private String kind;
  private String link;
  private String name;
  private String status;
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  public String getLink() {
    return this.link;
  }
  public A withLink(String link) {
    this.link=link; return (A) this;
  }
  public Boolean hasLink() {
    return this.link != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getStatus() {
    return this.status;
  }
  public A withStatus(String status) {
    this.status=status; return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObjectStatusFluentImpl that = (ObjectStatusFluentImpl) o;
    if (!java.util.Objects.equals(group, that.group)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(link, that.link)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  link,  name,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (link != null) { sb.append("link:"); sb.append(link + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  
}
